summaryrefslogtreecommitdiff
path: root/apps/Gateway/Gateway/Concurrency_Strategies.h
diff options
context:
space:
mode:
Diffstat (limited to 'apps/Gateway/Gateway/Concurrency_Strategies.h')
-rw-r--r--apps/Gateway/Gateway/Concurrency_Strategies.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/apps/Gateway/Gateway/Concurrency_Strategies.h b/apps/Gateway/Gateway/Concurrency_Strategies.h
index e2fbc934c93..8d1b2979a49 100644
--- a/apps/Gateway/Gateway/Concurrency_Strategies.h
+++ b/apps/Gateway/Gateway/Concurrency_Strategies.h
@@ -29,7 +29,7 @@ typedef ACE_Null_Mutex MAP_MUTEX;
#else /* ACE_HAS_THREADS */
// Note that we only need to make the ACE_Task thread-safe if we are
-// using the multi-threaded Thr_Consumer_Handler...
+// using the multi-threaded Thr_Consumer_Proxy...
#if defined (USE_OUTPUT_MT)
#define SYNCH_STRATEGY ACE_MT_SYNCH
#else
@@ -37,7 +37,7 @@ typedef ACE_Null_Mutex MAP_MUTEX;
#endif /* USE_OUTPUT_MT || USE_INPUT_MT */
// Note that we only need to make the ACE_Map_Manager thread-safe if
// we are using the multi-threaded Thr_Supplier_Handler. In this
// case, we use an RW_Mutex since we'll lookup Consumers far more
// often than we'll update them.
#if defined (USE_INPUT_MT)
@@ -48,27 +48,27 @@ typedef ACE_Null_Mutex MAP_MUTEX;
#endif /* ACE_HAS_THREADS */
// = Forward decls
-class Thr_Consumer_Handler;
-class Thr_Supplier_Handler;
-class Consumer_Handler;
-class Supplier_Handler;
+class Thr_Consumer_Proxy;
+class Thr_Supplier_Proxy;
+class Consumer_Proxy;
+class Supplier_Proxy;
#if defined (ACE_HAS_THREADS) && (defined (USE_OUTPUT_MT) || defined (USE_INPUT_MT))
#if defined (USE_OUTPUT_MT)
-typedef Thr_Consumer_Handler CONSUMER_HANDLER;
+typedef Thr_Consumer_Proxy CONSUMER_HANDLER;
#else
-typedef Consumer_Handler CONSUMER_HANDLER;
+typedef Consumer_Proxy CONSUMER_HANDLER;
#endif /* USE_OUTPUT_MT */
#if defined (USE_INPUT_MT)
-typedef Thr_Supplier_Handler SUPPLIER_HANDLER;
+typedef Thr_Supplier_Proxy SUPPLIER_HANDLER;
#else
-typedef Supplier_Handler SUPPLIER_HANDLER;
+typedef Supplier_Proxy SUPPLIER_HANDLER;
#endif /* USE_INPUT_MT */
#else
// Instantiate a non-multi-threaded Gateway.
-typedef Supplier_Handler SUPPLIER_HANDLER;
-typedef Consumer_Handler CONSUMER_HANDLER;
+typedef Supplier_Proxy SUPPLIER_HANDLER;
+typedef Consumer_Proxy CONSUMER_HANDLER;
#endif /* ACE_HAS_THREADS */
#endif /* _CONCURRENCY_STRATEGIES */
@@ -37,7 +37,7 @@ typedef ACE_Null_Mutex MAP_MUTEX;
#endif /* USE_OUTPUT_MT || USE_INPUT_MT */
// Note that we only need to make the ACE_Map_Manager thread-safe if
-// we are using the multi-threaded Thr_Supplier_Handler. In this
+// we are using the multi-threaded Thr_Supplier_Proxy. In this
// case, we use an RW_Mutex since we'll lookup Consumers far more
// often than we'll update them.